function [Msd,J]  = calc_relative_M_s(Msp)
%% calculate uncertain relative motion M12 = inv(M1) * M2
%  exponential representation
%
% Msp   rotation pair, Msp.Msp=[M1,M2]=[4,8], Msp.Csp = [12x12]
%
% Msd   relative rotation, Msd.Ms=[4x4], Msd.Cs=[6x6]
% J     [6x12] Jacobian
%
% wf 6/2020

% M1, M
Ms1    = Msp.Msp(:,1:4);
Msd.Ms = inv(Ms1) * Msp.Msp(:,5:8);

% inverse adjunct motion matrix
R1     = Ms1(1:3,1:3);
Z1     = Ms1(1:3,4);
M_1_ad_inv = [R1'            , zeros(3); ...
              R1'*calc_S(Z1)',     R1'];

% Jacobian and CovM
J      =  [-M_1_ad_inv , M_1_ad_inv];
Msd.Cs = J * Msp.Csp * J';

return
